@@ -274,6 +274,9 @@ int main(int argc, char *argv[])
                                       "name");
         parser.addOption(nameOption);
 
+        QCommandLineOption wolOption(QStringList() << "wol", "Send Wake-On-LAN / Magic Packet to <mac> and (optional) <port>.", "mac");
+        parser.addOption(wolOption);
+
 
 
         // Intense Traffic Generator
@@ -325,6 +328,8 @@ int main(int argc, char *argv[])
         bool ipv4  = parser.isSet(bindIPv4Option);
         bool http  = parser.isSet(httpOption);
 
+        bool wol = parser.isSet(wolOption);
+
         bool okbps = false;
         bool okrate = false;
         bool maxrate = parser.isSet(maxOption);
@@ -370,6 +375,36 @@ int main(int argc, char *argv[])
         if (argssize >= 1) {
             address = args[0];
         }
+
+        if(wol) {
+            QString targetMAC = parser.value(wolOption).trimmed().toUpper();
+            if (argssize >= 1) {
+                port = QString(args[0]).toUInt();
+            }
+            if(port < 1) {
+                port = 7;
+            }
+
+            Packet wolPkt = Packet::generateWakeOnLAN(targetMAC, port);
+
+            if(wolPkt.errorString.isEmpty()) {
+                OUTIF() << "Sending broadcast Wake-On-LAN to target: " + targetMAC + " on port " + QString::number(port);
+                udp = true;
+                tcp = false;
+                ssl = false;
+                http = false;
+                address = wolPkt.toIP;
+                data = wolPkt.hexString;
+
+            } else {
+                OUTIF() << "Error generating Wake-On-LAN: " + wolPkt.errorString;
+                OUTPUT();
+                return -1;
+            }
+
+        }
+
+
         if(http) {
             if(parser.isSet(httpOption)) {
                 if(httpMethod != "GET" && httpMethod != "POST") {
