@@ -56,6 +56,7 @@
 #include "cloudui.h"
 #include "postdatagen.h"
 #include "panelgenerator.h"
+#include "wakeonlan.h"
 
 int hexToInt(QChar hex);
 void parserMajorMinorBuild(QString sw, unsigned int &major, unsigned int &minor, unsigned int &build);
@@ -2784,3 +2785,54 @@ void MainWindow::on_udptcpComboBox_currentIndexChanged(int index)
     on_udptcpComboBox_currentIndexChanged("");
 }
 
+
+void MainWindow::on_actionWake_On_LAN_Magic_Packet_triggered()
+{
+    static QString previousMAC = "";
+    static int previousPortIndex = 0;
+    WakeOnLAN * wol = new WakeOnLAN(this);
+    wol->setTarget(previousMAC, previousPortIndex);
+    wol->setModal(true);
+    wol->exec();
+    if(!wol->generatedPacket.errorString.isEmpty()) {
+
+        QMessageBox msgBox;
+        msgBox.setWindowIcon(QIcon(":pslogo.png"));
+        msgBox.setWindowTitle(tr("Invalid MAC Address."));
+        msgBox.setStandardButtons(QMessageBox::Ok);
+        msgBox.setDefaultButton(QMessageBox::Ok);
+        msgBox.setIcon(QMessageBox::Critical);
+        msgBox.setText(wol->generatedPacket.errorString);
+        msgBox.setModal(true);
+        msgBox.exec();
+
+        on_actionWake_On_LAN_Magic_Packet_triggered();
+        wol->deleteLater();
+        return;
+    }
+
+    if(wol->generatedPacket.toIP.isEmpty()) {
+        wol->deleteLater();
+        return;
+    }
+
+    previousMAC = wol->mac;
+    previousPortIndex = wol->portIndex;
+
+    ui->packetIPEdit->setText(wol->generatedPacket.toIP);
+    ui->packetPortEdit->setText(QString::number(wol->generatedPacket.port));
+    ui->resendEdit->setText("0");
+    int findtext = ui->udptcpComboBox->findText(wol->generatedPacket.tcpOrUdp);
+    if (findtext > -1) {
+        ui->udptcpComboBox->setCurrentIndex(findtext);
+    }
+    ui->packetHexEdit->setText(wol->generatedPacket.hexString);
+    on_packetHexEdit_editingFinished();
+    on_udptcpComboBox_currentIndexChanged("");
+
+    if(ui->packetNameEdit->text().isEmpty()) {
+        ui->packetNameEdit->setFocus();
+    }
+    wol->deleteLater();
+}
+
